Index: mobile/android/base/java/org/mozilla/gecko/GeckoApplication.java |
=================================================================== |
--- a/mobile/android/base/java/org/mozilla/gecko/GeckoApplication.java |
+++ b/mobile/android/base/java/org/mozilla/gecko/GeckoApplication.java |
@@ -308,20 +308,20 @@ |
null); |
EventDispatcher.getInstance().registerBackgroundThreadListener(mListener, |
"PushServiceAndroidGCM:Configure", |
"Bookmark:Insert", |
"Image:SetAs", |
"Profile:Create", |
null); |
// Added AddOnBridge initialisation here for resending requests that for some reason, |
// couldn't be saved by the extension |
// See https://issues.adblockplus.org/ticket/2853 |
- org.adblockplus.browser.AddOnBridge.init(context); |
+ org.adblockplus.browser.ExtensionBridge.init(context); |
super.onCreate(); |
} |
/** |
@@ -308,20 +308,20 @@ |
"Profile:Create", |
null); |
- // Added AddOnBridge initialisation here for resending requests that for some reason, |
+ // Added ExtensionBridge initialisation here for resending requests that for some reason, |
// couldn't be saved by the extension |
// See https://issues.adblockplus.org/ticket/2853 |
* May be called when a new GeckoApplication object |
* replaces an old one due to assets change. |
*/ |